'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = run;

var _build = require('./build');

var _build2 = _interopRequireDefault(_build);

var _Hash = require('./utils/Hash');

var _Hash2 = _interopRequireDefault(_Hash);

var _PackageJSON = require('./utils/PackageJSON');

var _PackageJSON2 = _interopRequireDefault(_PackageJSON);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _deploy = require('./utils/deploy');

var _deploy2 = _interopRequireDefault(_deploy);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function run(options) {
  options = (0, _extends3.default)({
    transpile: true,
    folder: null
  }, options);

  var packages = ['.'];
  var packagesPath = _path2.default.resolve(process.cwd(), options.folder || '.');

  if (options.folder) {
    packages = _fsExtra2.default.readdirSync(packagesPath).filter(function (file) {
      return _fsExtra2.default.statSync(_path2.default.join(packagesPath, file)).isDirectory();
    });
  }

  packages.forEach(function (pkg) {
    var relPath = options.folder ? _path2.default.join(options.folder, pkg) : '.';

    console.log();
    console.log('# # # # # # # # # # # # # # # # # # # # # # # # # #');
    console.log('# ' + _chalk2.default.green.bold('Deploy for ' + pkg));
    console.log('# # # # # # # # # # # # # # # # # # # # # # # # # #');
    console.log();

    (0, _build2.default)({
      transpile: options.transpile,
      root: relPath
    });

    var hash = new _Hash2.default(relPath, _path2.default.join(relPath, 'build'));

    if (hash.changed()) {
      var sourcePath = _path2.default.resolve(process.cwd(), relPath);
      var targetPath = _path2.default.resolve(sourcePath, 'build');

      (0, _deploy2.default)(targetPath);

      var version = new _PackageJSON2.default(sourcePath).bump();

      hash.update();

      console.log(_chalk2.default.green.bold('Package deployed as version ' + version));
    } else {
      console.log(_chalk2.default.yellow.bold('Content not changed, deployment canceled'));
    }

    console.log();
  });
}
module.exports = exports.default;